==> nextcloud-app-notes-4.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/mk.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Белешки",
    "Reading notes from filesystem has failed." : "Неуспешно вчитување на белесшките.",
    "Error" : "Грешка",
    "New note" : "Нова белешка",
    "Distraction-free notes and writing" : "Пушување на белешки без одвлекување на вниманието",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](https://github.com/nextcloud/notes/blob/master/docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "Апликацијата Белешки е апликација за одвлекување бесплатен белешки за [Nextcloud] (https://www.nextcloud.com/). Обезбедува категории за подобра организација и поддржува форматирање користејќи [Markdown] (https://en.wikipedia.org/wiki/Markdown) синтакса. Белешките се зачувуваат како датотеки во вашиот Nextcloud, за да можете да ги гледате и уредувате истите со секој клиент на Nextcloud. Понатаму, посебна [REST API] (https://github.com/nextcloud/notes/blob/master/docs/api/README.md) дозволува лесна интеграција во трети апликации (во моментов, има апликации за белешки за [Android] (https://github.com/stefan-niedermann/nextcloud-notes) и [iOS] (https://github.com/owncloud/notes-iOS-App) кои овозможуваат удобен пристап до вашите белешки за Nextcloud). Дополнителни карактеристики вклучуваат белешки за обележување како омилени.",
    "Please see Nextcloud server log for details." : "За повеќе детали проверете ги записите во серверот.",
    "Deleted {title}" : "Избришана {title}",
    "Undo Delete" : "Врати бришење",
    "Note recovered" : "Белешката е вратена",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Имате незачувана белешка. Со напуштање на стрната нема да се зачуваат промените!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Избришана {number} белешка","Избришани {number} белешки"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Вратена {number} белешка","Вратени {number} белешки"],
    "Folder to store your notes" : "Папка за зачувување на вашите белешки",
    "File extension for new notes" : "Наставка на дадотека за нови белешки",
    "No notes yet" : "Сеуште нема забелешки",
    "All notes" : "Сите белешки",
    "Categories" : "Категории",
    "Loading …" : "Се вчитува…",
    "Today" : "Денес",
    "Yesterday" : "Вчера",
    "This week" : "Оваа недела",
    "Last week" : "Минатата недела",
    "This month" : "Овој месец",
    "Last month" : "Минатиот месец",
    "Rename" : "Преименувај",
    "Note's title" : "Наслов на белешката",
    "Delete note" : "Избриши белешка",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add to favorites" : "Додади во фаворити",
    "Error during preparing note for deletion." : "Грешка при обидот за бришење на белешката.",
    "Use current version" : "Користи ја моменталната верзија",
    "Empty note" : "Празна белешка",
    "Write …" : "Пишувај ...",
    "Details" : "Детали",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Уреди",
    "Preview" : "Преглед",
    "Exit full screen" : "Излез од цел екран",
    "Full screen" : "Цел екран",
    "Save failed. Click to retry." : "Неуспешно зачувување. Крикни за повторен обид.",
    "Error from Nextcloud server: {msg}" : "Грешка од серверот: {msg}",
    "Set category" : "Постави категорија",
    "Category" : "Категорија",
    "Uncategorized" : "Некатегоризирани",
    "Click here to save manually" : "Кликни тука за рачно зачувување",
    "Saving failed!" : "Неуспешно зачувување!",
    "Last modified: {date}" : "Скоро изменети: {date}",
    "Note has unsaved changes" : "Белешката има незачувани промени",
    "Subcategory" : "Подкатегорија",
    "_%n word_::_%n words_" : ["%n збор","%n зборови"],
    "_%n character_::_%n characters_" : ["%n карактер","%n карактери"],
    "Write down your thoughts without any distractions." : "Запишете ги мислите без одвлекување на вниманието.",
    "Use Markdown markups to style your text." : "Користете ознаки за означување за стилизирање на вашиот текст.",
    "Organize your notes in categories." : "Организирајте ги вашите белешки во категории.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте ја апликацијата за мобилен телефон за да можете да пристапувате до вашите белешки од секаде.",
    "Android app" : "Android апликација",
    "iOS app" : "iOS апликација",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Започнете да пишувате белешка со притискање на “{newnote}” во навигацијата на апликацијата.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да креирате поткатегории со употреба на „/“ како разграничувач помеѓу главната категорија и поткатегоријата, на пр. “{parent}/{sub}”.",
    "Note not found." : "Белешката не е пронајдена.",
    "Note is locked." : "Белешката е заклучена.",
    "Insufficient storage." : "Недоболно простор на складиштето.",
    "See JavaScript console and server log for details." : "Погледнете во конзолата JavaScript и записите во серверот за детали.",
    "Updating settings has failed." : "Неуспешно ажурирање на параметрите.",
    "Fetching notes for dashboard has failed." : "Неуспешно преземање на белешките на таблата.",
    "Fetching notes has failed." : "Неуспешно преземање на белешката.",
    "Fetching note {id} has failed." : "Неуспешно преземање на белешката {id}.",
    "Refreshing note {id} has failed." : "Неуспешно освежување на белешката {id}.",
    "Renaming note {id} has failed." : "Неуспешно преименување на белешката {id}.",
    "Creating new note has failed." : "Неуспешно креирање на нова белешка.",
    "Saving note {id} has failed." : "Неуспешни зачувување на белешката {id}.",
    "Updating title for note {id} has failed." : "Ажурирање на насловот на бешката е неуспешна {id}.",
    "Undo delete has failed for note {title}." : "Неуспешно враќање на белешката {title}.",
    "Deleting note {id} has failed." : "Неуспешно бришење на белешката {id}.",
    "Toggling favorite for note {id} has failed." : "Неуспешно поставување во омилени белешки за белешката {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешно ажурирање на категорија за белешките. Дали во папката може да зачувува?",
    "Updating the category for note {id} has failed." : "Неуспешно ажурирање на категорија за белешката {id}.",
    "Development Mode" : "Мод за програмери",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Се чини дека апликацијата за белешки е инсталирана од извор за развивање. Ве молиме инсталирајте ја официјалната <a href=\"%1$s\">Nextcloud App Store</a> апликација. Ако сакате сами да ја изградите апликацијата Белешки, следете ја следната <a href=\"%2$s\">документација за развивачи</a>."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-notes-4.7.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/notes/l10n/mk.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Белешки",
    "Reading notes from filesystem has failed." : "Неуспешно вчитување на белесшките.",
    "Error" : "Грешка",
    "New note" : "Нова белешка",
    "Distraction-free notes and writing" : "Пушување на белешки без одвлекување на вниманието",
    "Help" : "Помош",
    "Please see Nextcloud server log for details." : "За повеќе детали проверете ги записите во серверот.",
    "Deleted {title}" : "Избришана {title}",
    "Undo Delete" : "Врати бришење",
    "Note recovered" : "Белешката е вратена",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Имате незачувана белешка. Со напуштање на стрната нема да се зачуваат промените!",
    "_Deleted {number} note_::_Deleted {number} notes_" : ["Избришана {number} белешка","Избришани {number} белешки"],
    "_Recovered {number} note_::_Recovered {number} notes_" : ["Вратена {number} белешка","Вратени {number} белешки"],
    "Write down your thoughts without any distractions." : "Запишете ги мислите без одвлекување на вниманието.",
    "Organize your notes in categories." : "Организирајте ги вашите белешки во категории.",
    "Use Markdown markups to style your text." : "Користете ознаки за означување за стилизирање на вашиот текст.",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Започнете да пишувате белешка со притискање на “{newnote}” во навигацијата на апликацијата.",
    "Folder to store your notes" : "Папка за зачувување на вашите белешки",
    "File extension for new notes" : "Наставка на дадотека за нови белешки",
    "No notes yet" : "Сеуште нема забелешки",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Инсталирајте ја апликацијата за мобилен телефон за да можете да пристапувате до вашите белешки од секаде.",
    "All notes" : "Сите белешки",
    "Categories" : "Категории",
    "Loading …" : "Се вчитува…",
    "Today" : "Денес",
    "Yesterday" : "Вчера",
    "This week" : "Оваа недела",
    "Last week" : "Минатата недела",
    "This month" : "Овој месец",
    "Last month" : "Минатиот месец",
    "Rename" : "Преименувај",
    "Note's title" : "Наслов на белешката",
    "Details" : "Детали",
    "Delete note" : "Избриши белешка",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add to favorites" : "Додади во фаворити",
    "Error during preparing note for deletion." : "Грешка при обидот за бришење на белешката.",
    "Use current version" : "Користи ја моменталната верзија",
    "Empty note" : "Празна белешка",
    "Write …" : "Пишувај ...",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Уреди",
    "Preview" : "Преглед",
    "Exit full screen" : "Излез од цел екран",
    "Full screen" : "Цел екран",
    "Save failed. Click to retry." : "Неуспешно зачувување. Крикни за повторен обид.",
    "Error from Nextcloud server: {msg}" : "Грешка од серверот: {msg}",
    "Category" : "Категорија",
    "Uncategorized" : "Некатегоризирани",
    "Set category" : "Постави категорија",
    "Click here to save manually" : "Кликни тука за рачно зачувување",
    "Saving failed!" : "Неуспешно зачувување!",
    "Last modified: {date}" : "Скоро изменети: {date}",
    "Note has unsaved changes" : "Белешката има незачувани промени",
    "Subcategory" : "Подкатегорија",
    "_%n word_::_%n words_" : ["%n збор","%n зборови"],
    "_%n character_::_%n characters_" : ["%n карактер","%n карактери"],
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Можете да креирате поткатегории со употреба на „/“ како разграничувач помеѓу главната категорија и поткатегоријата, на пр. “{parent}/{sub}”.",
    "Note not found." : "Белешката не е пронајдена.",
    "Note is locked." : "Белешката е заклучена.",
    "Insufficient storage." : "Недоболно простор на складиштето.",
    "See JavaScript console and server log for details." : "Погледнете во конзолата JavaScript и записите во серверот за детали.",
    "Updating settings has failed." : "Неуспешно ажурирање на параметрите.",
    "Fetching notes for dashboard has failed." : "Неуспешно преземање на белешките на таблата.",
    "Fetching notes has failed." : "Неуспешно преземање на белешката.",
    "Fetching note {id} has failed." : "Неуспешно преземање на белешката {id}.",
    "Refreshing note {id} has failed." : "Неуспешно освежување на белешката {id}.",
    "Renaming note {id} has failed." : "Неуспешно преименување на белешката {id}.",
    "Creating new note has failed." : "Неуспешно креирање на нова белешка.",
    "Saving note {id} has failed." : "Неуспешни зачувување на белешката {id}.",
    "Updating title for note {id} has failed." : "Ажурирање на насловот на бешката е неуспешна {id}.",
    "Undo delete has failed for note {title}." : "Неуспешно враќање на белешката {title}.",
    "Deleting note {id} has failed." : "Неуспешно бришење на белешката {id}.",
    "Toggling favorite for note {id} has failed." : "Неуспешно поставување во омилени белешки за белешката {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Неуспешно ажурирање на категорија за белешките. Дали во папката може да зачувува?",
    "Updating the category for note {id} has failed." : "Неуспешно ажурирање на категорија за белешката {id}.",
    "Tasks" : "Задачи",
    "Development Mode" : "Мод за програмери",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Се чини дека апликацијата за белешки е инсталирана од извор за развивање. Ве молиме инсталирајте ја официјалната <a href=\"%1$s\">Nextcloud App Store</a> апликација. Ако сакате сами да ја изградите апликацијата Белешки, следете ја следната <a href=\"%2$s\">документација за развивачи</a>."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
